@@ -50,39 +50,47 @@ class Inventory(object):
 
         self.header = [
             "Host",
-            "Name",
-            "Type",
+            # "Name",
+            # "Type",
             "Tag",
             "Cluster",
-            "Label",
+            # "Label",
             "Service",
             "Services",
             "IP",
             "DNS",
-            "Project",
+            "Router",
+            "Locale",
+            "Timezone",
+            # "Project",
             "Owners",
             "Comment",
             "Description",
             "Keyfile",
-            "Status"]
+            # "Status"
+            ]
 
         self.order = [
             "host",
-            "name",
-            "type",
+            # "name",
+            # "type",
             "tag",
             "cluster",
-            "label",
+            # "label",
             "service",
             "services",
             "ip",
             "dns",
-            "project",
+            "router",
+            "locale",
+            "timezone",
+            # "project",
             "owners",
             "comment",
             "description",
             "keyfile",
-            "status"]
+            # "status"
+            ]
 
         self.entry = {}
         for key in self.order:
